@@ -6,13 +6,18 @@ from oarepo_runtime.i18n.ui_schema import (
     MultilingualUIField,
 )
 from oarepo_runtime.ui import marshmallow as l10n
-from oarepo_vocabularies.services.ui_schemas import HierarchyUISchema, I18nStrUIField
+from oarepo_runtime.ui.marshmallow import InvenioUISchema
+from oarepo_vocabularies.services.ui_schemas import (
+    HierarchyUISchema,
+    VocabularyI18nStrUIField,
+)
 
 from nr_metadata.ui_schema.identifiers import (
     NRAuthorityIdentifierUISchema,
     NRObjectIdentifierUISchema,
     NRSystemIdentifierUISchema,
 )
+from nr_metadata.ui_schema.subjects import NRSubjectListField
 
 
 class AdditionalTitlesUISchema(ma.Schema):
@@ -26,7 +31,7 @@ class NRAffiliationVocabularyUISchema(ma.Schema):
     """NRAffiliationVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     hierarchy = ma_fields.Nested(lambda: HierarchyUISchema())
     _version = ma_fields.String(data_key="@v", attribute="@v")
@@ -49,7 +54,7 @@ class NRAuthorityRoleVocabularyUISchema(ma.Schema):
     """NRAuthorityRoleVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -72,7 +77,7 @@ class NRResourceTypeVocabularyUISchema(ma.Schema):
     """NRResourceTypeVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -81,7 +86,7 @@ class NRSubjectUISchema(ma.Schema):
     """NRSubjectUISchema schema."""
 
     subjectScheme = ma_fields.String()
-    subject = MultilingualLocalizedUIField(I18nStrUIField())
+    subject = MultilingualUIField(I18nStrUIField())
     valueURI = ma_fields.String()
     classificationCode = ma_fields.String()
 
@@ -90,7 +95,7 @@ class NRSubjectCategoryVocabularyUISchema(ma.Schema):
     """NRSubjectCategoryVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -99,7 +104,7 @@ class NRLanguageVocabularyUISchema(ma.Schema):
     """NRLanguageVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -108,7 +113,7 @@ class NRLicenseVocabularyUISchema(ma.Schema):
     """NRLicenseVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -117,7 +122,7 @@ class NRAccessRightsVocabularyUISchema(ma.Schema):
     """NRAccessRightsVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -126,7 +131,7 @@ class NRItemRelationTypeVocabularyUISchema(ma.Schema):
     """NRItemRelationTypeVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -153,7 +158,7 @@ class NRFunderVocabularyUISchema(ma.Schema):
     """NRFunderVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -199,7 +204,7 @@ class NRCountryVocabularyUISchema(ma.Schema):
     """NRCountryVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = I18nStrUIField()
+    title = VocabularyI18nStrUIField()
     type = ma_fields.String()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
@@ -232,7 +237,7 @@ class NRCommonMetadataUISchema(ma.Schema):
     resourceType = ma_fields.Nested(lambda: NRResourceTypeVocabularyUISchema())
     dateAvailable = l10n.LocalizedEDTF()
     dateModified = l10n.LocalizedEDTF()
-    subjects = ma_fields.List(ma_fields.Nested(lambda: NRSubjectUISchema()))
+    subjects = NRSubjectListField(ma_fields.Nested(lambda: NRSubjectUISchema()))
     publishers = ma_fields.List(ma_fields.String())
     subjectCategories = ma_fields.List(
         ma_fields.Nested(lambda: NRSubjectCategoryVocabularyUISchema())
@@ -268,6 +273,6 @@ class NRCommonRecordUISchema(InvenioUISchema):
 
     metadata = ma_fields.Nested(lambda: NRCommonMetadataUISchema())
     _id = ma_fields.String(data_key="id", attribute="id")
-    created = l10n.LocalizedDate()
-    updated = l10n.LocalizedDate()
+    created = l10n.LocalizedDateTime()
+    updated = l10n.LocalizedDateTime()
     _schema = ma_fields.String(data_key="$schema", attribute="$schema")
