@@ -1,13 +1,9 @@
+from flask_babelex import lazy_gettext as _
 from invenio_records_resources.services import SearchOptions as InvenioSearchOptions
 
 from . import facets
 
 
-def _(x):
-    """Identity function for string extraction."""
-    return x
-
-
 class DocumentsSearchOptions(InvenioSearchOptions):
     """DocumentsRecord search options."""
 
@@ -36,8 +32,12 @@ class DocumentsSearchOptions(InvenioSearchOptions):
         "metadata_additionalTitles_title_lang": (
             facets.metadata_additionalTitles_title_lang
         ),
-        "metadata_additionalTitles_title_cs": facets.metadata_additionalTitles_title_cs,
-        "metadata_additionalTitles_title_en": facets.metadata_additionalTitles_title_en,
+        "metadata_additionalTitles_title_cs_keyword": (
+            facets.metadata_additionalTitles_title_cs_keyword
+        ),
+        "metadata_additionalTitles_title_en_keyword": (
+            facets.metadata_additionalTitles_title_en_keyword
+        ),
         "metadata_additionalTitles_title_value_keyword": (
             facets.metadata_additionalTitles_title_value_keyword
         ),
@@ -106,8 +106,12 @@ class DocumentsSearchOptions(InvenioSearchOptions):
         "metadata_dateModified": facets.metadata_dateModified,
         "metadata_subjects_subjectScheme": facets.metadata_subjects_subjectScheme,
         "metadata_subjects_subject_lang": facets.metadata_subjects_subject_lang,
-        "metadata_subjects_subject_cs": facets.metadata_subjects_subject_cs,
-        "metadata_subjects_subject_en": facets.metadata_subjects_subject_en,
+        "metadata_subjects_subject_cs_keyword": (
+            facets.metadata_subjects_subject_cs_keyword
+        ),
+        "metadata_subjects_subject_en_keyword": (
+            facets.metadata_subjects_subject_en_keyword
+        ),
         "metadata_subjects_subject_value_keyword": (
             facets.metadata_subjects_subject_value_keyword
         ),
@@ -124,16 +128,16 @@ class DocumentsSearchOptions(InvenioSearchOptions):
         "metadata_languages_type": facets.metadata_languages_type,
         "metadata_languages__version": facets.metadata_languages__version,
         "metadata_abstract_lang": facets.metadata_abstract_lang,
-        "metadata_abstract_cs": facets.metadata_abstract_cs,
-        "metadata_abstract_en": facets.metadata_abstract_en,
+        "metadata_abstract_cs_keyword": facets.metadata_abstract_cs_keyword,
+        "metadata_abstract_en_keyword": facets.metadata_abstract_en_keyword,
         "metadata_abstract_value_keyword": facets.metadata_abstract_value_keyword,
         "metadata_methods_lang": facets.metadata_methods_lang,
-        "metadata_methods_cs": facets.metadata_methods_cs,
-        "metadata_methods_en": facets.metadata_methods_en,
+        "metadata_methods_cs_keyword": facets.metadata_methods_cs_keyword,
+        "metadata_methods_en_keyword": facets.metadata_methods_en_keyword,
         "metadata_methods_value_keyword": facets.metadata_methods_value_keyword,
         "metadata_technicalInfo_lang": facets.metadata_technicalInfo_lang,
-        "metadata_technicalInfo_cs": facets.metadata_technicalInfo_cs,
-        "metadata_technicalInfo_en": facets.metadata_technicalInfo_en,
+        "metadata_technicalInfo_cs_keyword": facets.metadata_technicalInfo_cs_keyword,
+        "metadata_technicalInfo_en_keyword": facets.metadata_technicalInfo_en_keyword,
         "metadata_technicalInfo_value_keyword": (
             facets.metadata_technicalInfo_value_keyword
         ),
@@ -270,8 +274,8 @@ class DocumentsSearchOptions(InvenioSearchOptions):
             facets.metadata_geoLocations_geoLocationPoint_pointLatitude
         ),
         "metadata_accessibility_lang": facets.metadata_accessibility_lang,
-        "metadata_accessibility_cs": facets.metadata_accessibility_cs,
-        "metadata_accessibility_en": facets.metadata_accessibility_en,
+        "metadata_accessibility_cs_keyword": facets.metadata_accessibility_cs_keyword,
+        "metadata_accessibility_en_keyword": facets.metadata_accessibility_en_keyword,
         "metadata_accessibility_value_keyword": (
             facets.metadata_accessibility_value_keyword
         ),
